@@ -146,7 +146,8 @@ import datetime as dt
 
 import numpy as np
 import pandas as pd
-from scipy.stats import _distn_infrastructure, norm, rv_continuous, rv_discrete
+from scipy.stats import norm, rv_continuous, rv_discrete
+from scipy.stats.distributions import rv_frozen
 
 from statsmodels.base.covtype import descriptions
 import statsmodels.base.wrapper as wrap
@@ -651,9 +652,13 @@ class ETSModel(base.StateSpaceMLEModel):
         """
         Prepare data for use in the state space representation
         """
-        endog = np.array(data.orig_endog, order="C")
+        endog = np.require(data.orig_endog, requirements="WC")
         if endog.ndim != 1:
             raise ValueError("endog must be 1-dimensional")
+        if endog.dtype != np.double:
+            endog = np.require(
+                data.orig_endog, requirements="WC", dtype=float
+            )
         return endog, None
 
     @property
@@ -789,7 +794,11 @@ class ETSModel(base.StateSpaceMLEModel):
         if self.initialization_method != "estimated":
             internal[4] = self.initial_level
             internal[5] = self.initial_trend
-            internal[6:] = self.initial_seasonal
+            if np.isscalar(self.initial_seasonal):
+                internal[6:] = self.initial_seasonal
+            else:
+                # See GH 7893
+                internal[6:] = self.initial_seasonal[::-1]
         return internal
 
     def _model_params(self, internal):
@@ -1029,7 +1038,7 @@ class ETSModel(base.StateSpaceMLEModel):
 
             # check if we have fixed parameters and remove them from the
             # parameter vector
-            is_fixed = np.zeros(self._k_params_internal, dtype=int)
+            is_fixed = np.zeros(self._k_params_internal, dtype=np.int64)
             fixed_values = np.empty_like(internal_start_params)
             params_without_fixed = []
             kwargs["bounds"] = []
@@ -1135,10 +1144,12 @@ class ETSModel(base.StateSpaceMLEModel):
             data = self.endog
 
         if is_fixed is None:
-            is_fixed = np.zeros(self._k_params_internal, dtype=int)
+            is_fixed = np.zeros(self._k_params_internal, dtype=np.int64)
             fixed_values = np.empty(
                 self._k_params_internal, dtype=params.dtype
             )
+        else:
+            is_fixed = np.ascontiguousarray(is_fixed, dtype=np.int64)
 
         self._smoothing_func(
             params,
@@ -1158,7 +1169,7 @@ class ETSModel(base.StateSpaceMLEModel):
             # parameterizations, we clip negative values to very small positive
             # values so that the log-transformation yields very large negative
             # values.
-            yhat[yhat <= 0] = 1 / (1e-8 * (1 + np.abs(yhat[yhat < 0])))
+            yhat[yhat <= 0] = 1 / (1e-8 * (1 + np.abs(yhat[yhat <= 0])))
             logL -= np.sum(np.log(yhat))
         return logL
 
@@ -1194,7 +1205,7 @@ class ETSModel(base.StateSpaceMLEModel):
 
         .. math::
 
-           s^2 = \frac{1}{n}\sum\limits_{t=1}^n \frac{\hat{y}_t - y_t}{k_t}
+           s^2 = \frac{1}{n}\sum\limits_{t=1}^n \frac{(\hat{y}_t - y_t)^2}{k_t}
 
         where :math:`k_t = 1` for the additive error model and :math:`k_t =
         y_t` for the multiplicative error model.
@@ -1243,7 +1254,7 @@ class ETSModel(base.StateSpaceMLEModel):
         internal_params = self._internal_params(params)
         yhat = np.zeros(self.nobs)
         xhat = np.zeros((self.nobs, self._k_states_internal))
-        is_fixed = np.zeros(self._k_params_internal, dtype=int)
+        is_fixed = np.zeros(self._k_params_internal, dtype=np.int64)
         fixed_values = np.empty(self._k_params_internal, dtype=params.dtype)
         self._smoothing_func(
             internal_params, self.endog, yhat, xhat, is_fixed, fixed_values
@@ -1407,7 +1418,8 @@ class ETSResults(base.StateSpaceMLEResults):
             self.smoothing_trend = self.beta
         if self.has_seasonal:
             self.season = states[:, self.model._seasonal_index]
-            self.initial_seasonal = internal_params[6:]
+            # See GH 7893
+            self.initial_seasonal = internal_params[6:][::-1]
             self.initial_state[
                 self.model._seasonal_index :
             ] = self.initial_seasonal
@@ -1764,7 +1776,7 @@ class ETSResults(base.StateSpaceMLEResults):
         start_params = self._get_prediction_params(start_idx)
         x = np.zeros((nsimulations, self.model._k_states_internal))
         # is fixed and fixed values are dummy arguments
-        is_fixed = np.zeros(len(start_params), dtype=int)
+        is_fixed = np.zeros(len(start_params), dtype=np.int64)
         fixed_values = np.zeros_like(start_params)
         (
             alpha,
@@ -1813,7 +1825,7 @@ class ETSResults(base.StateSpaceMLEResults):
         elif isinstance(random_errors, (rv_continuous, rv_discrete)):
             params = random_errors.fit(self.resid)
             eps = random_errors.rvs(*params, size=(nsimulations, repetitions))
-        elif isinstance(random_errors, _distn_infrastructure.rv_frozen):
+        elif isinstance(random_errors, rv_frozen):
             eps = random_errors.rvs(size=(nsimulations, repetitions))
         else:
             raise ValueError("Argument random_errors has unexpected value!")
@@ -2298,7 +2310,7 @@ class PredictionResults:
                 self.simulation_results = pd.concat(sim_results, axis=0)
             else:
                 self.simulation_results = np.concatenate(sim_results, axis=0)
-            self.forecast_variance = self.simulation_results.var(1)
+            self.forecast_variance = self.simulation_results.var(axis=1)
         else:  # method == 'exact'
             steps = np.ones(ndynamic + nsmooth)
             if ndynamic > 0:
