@@ -69,7 +69,7 @@ class SARIMAX(MLEModel):
         Whether or not to assume the endogenous observations `endog` were
         measured with error. Default is False.
     time_varying_regression : bool, optional
-        Used when an explanatory variables, `exog`, are provided provided
+        Used when an explanatory variables, `exog`, are provided
         to select whether or not coefficients on the exogenous regressors are
         allowed to vary over time. Default is False.
     mle_regression : bool, optional
@@ -322,13 +322,14 @@ class SARIMAX(MLEModel):
                  enforce_stationarity=True, enforce_invertibility=True,
                  hamilton_representation=False, concentrate_scale=False,
                  trend_offset=1, use_exact_diffuse=False, dates=None,
-                 freq=None, missing='none', **kwargs):
+                 freq=None, missing='none', validate_specification=True,
+                 **kwargs):
 
         self._spec = SARIMAXSpecification(
             endog, exog=exog, order=order, seasonal_order=seasonal_order,
             trend=trend, enforce_stationarity=None, enforce_invertibility=None,
             concentrate_scale=concentrate_scale, dates=dates, freq=freq,
-            missing=missing)
+            missing=missing, validate_specification=validate_specification)
         self._params = SARIMAXParams(self._spec)
 
         # Save given orders
@@ -510,7 +511,7 @@ class SARIMAX(MLEModel):
         self.k_posdef = k_posdef
 
         # Initialize the statespace
-        super(SARIMAX, self).__init__(
+        super().__init__(
             endog, exog=exog, k_states=k_states, k_posdef=k_posdef, **kwargs
         )
 
@@ -544,7 +545,7 @@ class SARIMAX(MLEModel):
             self.initialize_default()
 
     def prepare_data(self):
-        endog, exog = super(SARIMAX, self).prepare_data()
+        endog, exog = super().prepare_data()
 
         # Perform simple differencing if requested
         if (self.simple_differencing and
@@ -594,7 +595,7 @@ class SARIMAX(MLEModel):
         These initialization steps must occur following the parent class
         __init__ function calls.
         """
-        super(SARIMAX, self).initialize()
+        super().initialize()
 
         # Cache the indexes of included polynomial orders (for update below)
         # (but we do not want the index of the constant term, so exclude the
@@ -759,7 +760,7 @@ class SARIMAX(MLEModel):
                 transition[start:end, start:end] = seasonal_companion
 
                 # i
-                for i in range(d + 1, self._k_seasonal_diff):
+                if d < self._k_seasonal_diff - 1:
                     transition[start, end + self.seasonal_periods - 1] = 1
 
                 # \iota
@@ -897,7 +898,7 @@ class SARIMAX(MLEModel):
             params_ma = params[offset:k_params_ma + offset]
             offset += k_params_ma
         if residuals is not None:
-            if len(residuals) > 1:
+            if len(residuals) > max(1, k_params_ma):
                 params_variance = (residuals[k_params_ma:] ** 2).mean()
             else:
                 params_variance = np.var(endog)
@@ -975,7 +976,7 @@ class SARIMAX(MLEModel):
         )
         if invalid_ma:
             warn('Non-invertible starting MA parameters found.'
-                 ' Using zeros as starting parameters.')
+                 ' Using zeros as starting parameters.', UserWarning)
             params_ma *= 0
 
         # Seasonal Parameters
@@ -1014,9 +1015,9 @@ class SARIMAX(MLEModel):
         if self.state_regression and self.time_varying_regression:
             # TODO how to set the initial variance parameters?
             params_exog_variance = [1] * self._k_exog
-        if (self.state_error and type(params_variance) == list and
+        if (self.state_error and type(params_variance) is list and
                 len(params_variance) == 0):
-            if not (type(params_seasonal_variance) == list and
+            if not (type(params_seasonal_variance) is list and
                     len(params_seasonal_variance) == 0):
                 params_variance = params_seasonal_variance
             elif self._k_exog > 0:
@@ -1026,7 +1027,10 @@ class SARIMAX(MLEModel):
         params_measurement_variance = 1 if self.measurement_error else []
 
         # We want to bound the starting variance away from zero
-        params_variance = np.atleast_1d(max(np.array(params_variance), 1e-10))
+        params_variance = np.atleast_1d(np.array(params_variance))
+        if params_variance.size:
+            # Avoid comparisons with empty arrays due to changes in NumPy 2.2
+            params_variance = np.atleast_1d(max(params_variance[0], 1e-10))
 
         # Remove state variance as parameter if scale is concentrated out
         if self.concentrate_scale:
@@ -1488,7 +1492,7 @@ class SARIMAX(MLEModel):
         return unconstrained
 
     def _validate_can_fix_params(self, param_names):
-        super(SARIMAX, self)._validate_can_fix_params(param_names)
+        super()._validate_can_fix_params(param_names)
         model_names = self.model_names
 
         items = [
@@ -1731,22 +1735,28 @@ class SARIMAX(MLEModel):
         # Create extended model
         if extend_kwargs is None:
             extend_kwargs = {}
-        if not self.simple_differencing and self._k_trend > 0:
+        if not self.simple_differencing and self.k_trend > 0:
             extend_kwargs.setdefault(
                 'trend_offset', self.trend_offset + self.nobs)
+        extend_kwargs.setdefault('validate_specification', False)
         mod_extend = self.clone(
             endog=tmp_endog, exog=tmp_exog, **extend_kwargs)
         mod_extend.update(params, transformed=transformed,
-                          includes_fixed=includes_fixed)
+                          includes_fixed=includes_fixed,)
 
-        # Retrieve the extensions to the time-varying system matrices
-        # and put them in kwargs
+        # Retrieve the extensions to the time-varying system matrices and
+        # put them in kwargs
         for name in self.ssm.shapes.keys():
-            if name == 'obs':
+            if name == 'obs' or name in kwargs:
                 continue
-            if getattr(self.ssm, name).shape[-1] > 1:
-                mat = getattr(mod_extend.ssm, name)
-                kwargs[name] = mat[..., -out_of_sample:]
+            original = getattr(self.ssm, name)
+            extended = getattr(mod_extend.ssm, name)
+            so = original.shape[-1]
+            se = extended.shape[-1]
+            if ((so > 1 or se > 1) or (
+                    so == 1 and self.nobs == 1 and
+                    np.any(original[..., 0] != extended[..., 0]))):
+                kwargs[name] = extended[..., -out_of_sample:]
 
         return kwargs
 
@@ -1796,8 +1806,7 @@ class SARIMAXResults(MLEResults):
     """
     def __init__(self, model, params, filter_results, cov_type=None,
                  **kwargs):
-        super(SARIMAXResults, self).__init__(model, params, filter_results,
-                                             cov_type, **kwargs)
+        super().__init__(model, params, filter_results, cov_type, **kwargs)
 
         self.df_resid = np.inf  # attribute required for wald tests
 
@@ -1872,13 +1881,17 @@ class SARIMAXResults(MLEResults):
             end += k
             setattr(self, '_params_%s' % name, self.params[start:end])
             start += k
+        # GH7527, all terms must be defined
+        all_terms = ['ar', 'ma', 'seasonal_ar', 'seasonal_ma', 'variance']
+        for name in set(all_terms).difference(self.param_terms):
+            setattr(self, '_params_%s' % name, np.empty(0))
 
         # Handle removing data
         self._data_attr_model.extend(['orig_endog', 'orig_exog'])
 
     def extend(self, endog, exog=None, **kwargs):
         kwargs.setdefault('trend_offset', self.nobs + 1)
-        return super(SARIMAXResults, self).extend(endog, exog=exog, **kwargs)
+        return super().extend(endog, exog=exog, **kwargs)
 
     @cache_readonly
     def arroots(self):
@@ -2004,11 +2017,12 @@ class SARIMAXResults(MLEResults):
                                self.model.seasonal_periods))
             if not order == '':
                 order += 'x'
-        model_name = (
-            '%s%s%s' % (self.model.__class__.__name__, order, seasonal_order)
-            )
-        return super(SARIMAXResults, self).summary(
-            alpha=alpha, start=start, title='SARIMAX Results',
+        model_name = f'{self.model.__class__.__name__}{order}{seasonal_order}'
+
+        return super().summary(
+            alpha=alpha,
+            start=start,
+            title='SARIMAX Results',
             model_name=model_name
         )
 
